Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1533)

Unified Diff: remoting/host/it2me/it2me_host.h

Issue 1643793002: Add policy to restrict client domain for Me2Me. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix remoting_perftests compile. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/policy/resources/policy_templates.json ('k') | remoting/host/it2me/it2me_host.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/it2me/it2me_host.h
diff --git a/remoting/host/it2me/it2me_host.h b/remoting/host/it2me/it2me_host.h
index aedb9ba734874e44b0d9362d758f24fd4021488b..e1e6076e1e49d0236ac8c56760039bc7ed8231be 100644
--- a/remoting/host/it2me/it2me_host.h
+++ b/remoting/host/it2me/it2me_host.h
@@ -133,9 +133,10 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
// Called when malformed policies are detected.
void OnPolicyError();
- // Handlers for NAT traversal and host domain policies.
+ // Handlers for NAT traversal and domain policies.
void UpdateNatPolicy(bool nat_traversal_enabled);
void UpdateHostDomainPolicy(const std::string& host_domain);
+ void UpdateClientDomainPolicy(const std::string& client_domain);
void Shutdown();
@@ -165,7 +166,8 @@ class It2MeHost : public base::RefCountedThreadSafe<It2MeHost>,
// Host the current nat traversal policy setting.
bool nat_traversal_enabled_;
- // The host domain policy setting.
+ // The client and host domain policy setting.
+ std::string required_client_domain_;
std::string required_host_domain_;
// Indicates whether or not a policy has ever been read. This is to ensure
« no previous file with comments | « components/policy/resources/policy_templates.json ('k') | remoting/host/it2me/it2me_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698